#!/bin/bash
#
# author           : George Vlahavas (vlahavas~AT~gmail~DOT~com, gapan@zenwalk forums)
# source location  : http://www.chiark.greenend.org.uk/~sgtatham/puzzles/
# source           : http://www.chiark.greenend.org.uk/~sgtatham/puzzles/puzzles-r7636.tar.gz

# Package name
NAME="puzzles"
# Package version
VERSION="r7636"
# Source code URL
SOURCE="http://www.chiark.greenend.org.uk/~sgtatham/puzzles/puzzles-$VERSION.tar.gz"
# Help file URL
HELPFILE="http://www.chiark.greenend.org.uk/~sgtatham/puzzles/puzzles.chm"
# Files that should be placed in /usr/doc/package-version/
DOCS="HACKING LICENCE README puzzles.txt"
# Puzzlespanel version
PPVERSION="0.1"
# Puzzles panel source URL
PPSOURCE="http://users.zenwalk.org/user-accounts/gapan/puzzles/puzzlespanel-$PPVERSION.tar.gz"
# Puzzlespanel docs
PPDOCS="AUTHORS COPYING ChangeLog"

CWD=`pwd`
PKG="$CWD/$NAME-install"
ARCH="i486"
CPU="i686"
BUILD="48.1"

#
# building-computer dependent: the number of parallel 'jobs' of 'make'
#
# 'heavy' computer: 6 build-jobs at once
#
#numjobs='-j6'
#
# 'light' computer: 2 build-jobs at once
#
numjobs='-j2'

rm -rf $PKG
mkdir -p $PKG

# Check to see if source is present. If it's not, download it
rm -rf $NAME-$VERSION
if [ -f $NAME-$VERSION.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c $SOURCE
fi

# Check to see if the chm help file is present. If it's not, download it
if [ -f puzzles.chm ]; then
	echo "Help file already here, no need to download";
else
 	echo "Downloading help file"
	wget -c $HELPFILE
fi

# Check to see if the puzzlespanel source is present. If it's not, download it
if [ -f puzzles.chm ]; then
	echo "Puzzlespanel source already here, no need to download";
else
 	echo "Downloading help file"
	wget -c $PPSOURCE
fi

# Unpack source
tar xvzf $NAME-$VERSION.tar.gz

# Unpack puzzlespanel source
tar xvzf puzzlespanel-$PPVERSION.tar.gz

# No configure script so we just do make
cd $NAME-$VERSION
export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
export CXXFLAGS="-O2 -march=$ARCH -mtune=$CPU"
# Patch makefile to use the proper flags
sed -i -e 's/-O2/-O2 -march=i486 -mtune=i686/' Makefile
make $numjobs

# There is no make install rule so we just copy executables to
# a temporary /usr/bin
mkdir -p $PKG/usr/bin
cp -a \
	blackbox bridges cube dominosa fifteen filling fillingsolver flip \
	galaxies galaxiespicture galaxiessolver guess inertia latincheck \
	lightup lightupsolver loopy map mapsolver mineobfusc mines net \
	netslide pattern patternsolver pegs rect samegame sixteen slant \
	slantsolver solo solosolver tents tentssolver twiddle unequal \
	unequalsolver untangle \
		$PKG/usr/bin

# Copy icons to the right place
mkdir -p $PKG/usr/share/icons/hicolor/48x48/apps
cd $CWD/$NAME-$VERSION/icons
cp -a \
	blackbox-48d8.png bridges-48d8.png cube-48d8.png dominosa-48d8.png \
	fifteen-48d8.png filling-48d8.png flip-48d8.png galaxies-48d8.png \
	guess-48d8.png inertia-48d8.png lightup-48d8.png loopy-48d8.png \
	map-48d8.png mines-48d8.png net-48d8.png netslide-48d8.png \
	pattern-48d8.png pegs-48d8.png rect-48d8.png samegame-48d8.png \
	sixteen-48d8.png slant-48d8.png solo-48d8.png tents-48d8.png \
	twiddle-48d8.png unequal-48d8.png untangle-48d8.png \
		$PKG/usr/share/icons/hicolor/48x48/apps

# Change the name of all main binaries to puzzles-puzzlename instead of just
# puzzlename because some names are likely to cause trouble (like blackbox).
# Puzzle solver names are not changed.
cd $PKG/usr/bin

GAMES="blackbox bridges cube dominosa fifteen filling flip \
	galaxies guess inertia latincheck lightup loopy map mines net \
	netslide pattern pegs rect samegame sixteen slant \
	solo tents twiddle unequal untangle"
for i in $GAMES; do mv $i puzzles-$i; done

# Also change the names of icons
cd $PKG/usr/share/icons/hicolor/48x48/apps
ICONS="blackbox-48d8.png bridges-48d8.png cube-48d8.png dominosa-48d8.png \
	fifteen-48d8.png filling-48d8.png flip-48d8.png galaxies-48d8.png \
	guess-48d8.png inertia-48d8.png lightup-48d8.png loopy-48d8.png \
	map-48d8.png mines-48d8.png net-48d8.png netslide-48d8.png \
	pattern-48d8.png pegs-48d8.png rect-48d8.png samegame-48d8.png \
	sixteen-48d8.png slant-48d8.png solo-48d8.png tents-48d8.png \
	twiddle-48d8.png unequal-48d8.png untangle-48d8.png"
for i in $ICONS; do mv $i puzzles-$i; done

# Copy Docs
mkdir -p $PKG/usr/doc/$NAME-$VERSION
cd $CWD/$NAME-$VERSION
cp -a $DOCS	$PKG/usr/doc/$NAME-$VERSION

# Also add the .chm help file
cp -a $CWD/puzzles.chm $PKG/usr/doc/$NAME-$VERSION

# Add the build-file in the package
mkdir -p $PKG/usr/src/$NAME-$VERSION
cp "$CWD/build-$NAME.sh" "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"
chmod a+x "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"

# Create package install directory
mkdir $PKG/install

# Create the slack-desc file
cat > $PKG/install/slack-desc << END
$NAME: puzzles - Simon Tatham's Portable Puzzle Collection
$NAME:
$NAME: A collection of small computer programs which implement
$NAME: one-player puzzle games
$NAME:
$NAME:
$NAME:
$NAME:
$NAME:
$NAME:
$NAME:
END

#
# Create the desktop entries
#
mkdir -p $PKG/usr/share/puzzles/applications

# Create desktop entry for blackbox
cat > $PKG/usr/share/puzzles/applications/puzzles-blackbox.desktop <<EOF
[Desktop Entry]
Encoding=UTF-8
Name=Blackbox
Comment=Puzzle
Exec=puzzles-blackbox
Terminal=false
Type=Application
Categories=Game;LogicGame;
Icon=puzzles-blackbox-48d8
EOF

# Create desktop entry for bridges
cat > $PKG/usr/share/puzzles/applications/puzzles-bridges.desktop <<EOF
[Desktop Entry]
Encoding=UTF-8
Name=Bridges
Comment=Puzzle
Exec=puzzles-bridges
Terminal=false
Type=Application
Categories=Game;LogicGame;
Icon=puzzles-bridges-48d8
EOF

# Create desktop entry for cube
cat > $PKG/usr/share/puzzles/applications/puzzles-cube.desktop <<EOF
[Desktop Entry]
Encoding=UTF-8
Name=Cube
Comment=Puzzle
Exec=puzzles-cube
Terminal=false
Type=Application
Categories=Game;LogicGame;
Icon=puzzles-cube-48d8
EOF

# Create desktop entry for dominosa
cat > $PKG/usr/share/puzzles/applications/puzzles-dominosa.desktop <<EOF
[Desktop Entry]
Encoding=UTF-8
Name=Dominosa
Comment=Puzzle
Exec=puzzles-dominosa
Terminal=false
Type=Application
Categories=Game;LogicGame;
Icon=puzzles-dominosa-48d8
EOF

# Create desktop entry for fifteen
cat > $PKG/usr/share/puzzles/applications/puzzles-fifteen.desktop <<EOF
[Desktop Entry]
Encoding=UTF-8
Name=Fifteen
Comment=Puzzle
Exec=puzzles-fifteen
Terminal=false
Type=Application
Categories=Game;LogicGame;
Icon=puzzles-fifteen-48d8
EOF

# Create desktop entry for filling
cat > $PKG/usr/share/puzzles/applications/puzzles-filling.desktop <<EOF
[Desktop Entry]
Encoding=UTF-8
Name=Filling
Comment=Puzzle
Exec=puzzles-filling
Terminal=false
Type=Application
Categories=Game;LogicGame;
Icon=puzzles-filling-48d8
EOF

# Create desktop entry for flip
cat > $PKG/usr/share/puzzles/applications/puzzles-flip.desktop <<EOF
[Desktop Entry]
Encoding=UTF-8
Name=Flip
Comment=Puzzle
Exec=puzzles-flip
Terminal=false
Type=Application
Categories=Game;LogicGame;
Icon=puzzles-flip-48d8
EOF

# Create desktop entry for galaxies
cat > $PKG/usr/share/puzzles/applications/puzzles-galaxies.desktop <<EOF
[Desktop Entry]
Encoding=UTF-8
Name=Galaxies
Comment=Puzzle
Exec=puzzles-galaxies
Terminal=false
Type=Application
Categories=Game;LogicGame;
Icon=puzzles-galaxies-48d8
EOF

# Create desktop entry for guess
cat > $PKG/usr/share/puzzles/applications/puzzles-guess.desktop <<EOF
[Desktop Entry]
Encoding=UTF-8
Name=Guess
Comment=Puzzle
Exec=puzzles-guess
Terminal=false
Type=Application
Categories=Game;LogicGame;
Icon=puzzles-guess-48d8
EOF

# Create desktop entry for inertia
cat > $PKG/usr/share/puzzles/applications/puzzles-inertia.desktop <<EOF
[Desktop Entry]
Encoding=UTF-8
Name=Inertia
Comment=Puzzle
Exec=puzzles-inertia
Terminal=false
Type=Application
Categories=Game;LogicGame;
Icon=puzzles-inertia-48d8
EOF

# Create desktop entry for lightup
cat > $PKG/usr/share/puzzles/applications/puzzles-lightup.desktop <<EOF
[Desktop Entry]
Encoding=UTF-8
Name=Lightup
Comment=Puzzle
Exec=puzzles-lightup
Terminal=false
Type=Application
Categories=Game;LogicGame;
Icon=puzzles-lightup-48d8
EOF

# Create desktop entry for loopy
cat > $PKG/usr/share/puzzles/applications/puzzles-loopy.desktop <<EOF
[Desktop Entry]
Encoding=UTF-8
Name=Loopy
Comment=Puzzle
Exec=puzzles-loopy
Terminal=false
Type=Application
Categories=Game;LogicGame;
Icon=puzzles-loopy-48d8
EOF

# Create desktop entry for map
cat > $PKG/usr/share/puzzles/applications/puzzles-map.desktop <<EOF
[Desktop Entry]
Encoding=UTF-8
Name=Map
Comment=Puzzle
Exec=puzzles-map
Terminal=false
Type=Application
Categories=Game;LogicGame;
Icon=puzzles-map-48d8
EOF

# Create desktop entry for mines
cat > $PKG/usr/share/puzzles/applications/puzzles-mines.desktop <<EOF
[Desktop Entry]
Encoding=UTF-8
Name=Mines
Comment=Puzzle
Exec=puzzles-mines
Terminal=false
Type=Application
Categories=Game;LogicGame;
Icon=puzzles-mines-48d8
EOF

# Create desktop entry for net
cat > $PKG/usr/share/puzzles/applications/puzzles-net.desktop <<EOF
[Desktop Entry]
Encoding=UTF-8
Name=Net
Comment=Puzzle
Exec=puzzles-net
Terminal=false
Type=Application
Categories=Game;LogicGame;
Icon=puzzles-net-48d8
EOF

# Create desktop entry for netslide
cat > $PKG/usr/share/puzzles/applications/puzzles-netslide.desktop <<EOF
[Desktop Entry]
Encoding=UTF-8
Name=Netslide
Comment=Puzzle
Exec=puzzles-netslide
Terminal=false
Type=Application
Categories=Game;LogicGame;
Icon=puzzles-netslide-48d8
EOF

# Create desktop entry for pattern
cat > $PKG/usr/share/puzzles/applications/puzzles-pattern.desktop <<EOF
[Desktop Entry]
Encoding=UTF-8
Name=Pattern
Comment=Puzzle
Exec=puzzles-pattern
Terminal=false
Type=Application
Categories=Game;LogicGame;
Icon=puzzles-pattern-48d8
EOF

# Create desktop entry for pegs
cat > $PKG/usr/share/puzzles/applications/puzzles-pegs.desktop <<EOF
[Desktop Entry]
Encoding=UTF-8
Name=Pegs
Comment=Puzzle
Exec=puzzles-pegs
Terminal=false
Type=Application
Categories=Game;LogicGame;
Icon=puzzles-pegs-48d8
EOF

# Create desktop entry for rect
cat > $PKG/usr/share/puzzles/applications/puzzles-rect.desktop <<EOF
[Desktop Entry]
Encoding=UTF-8
Name=Rect
Comment=Puzzle
Exec=puzzles-rect
Terminal=false
Type=Application
Categories=Game;LogicGame;
Icon=puzzles-rect-48d8
EOF

# Create desktop entry for samegame
cat > $PKG/usr/share/puzzles/applications/puzzles-samegame.desktop <<EOF
[Desktop Entry]
Encoding=UTF-8
Name=Samegame
Comment=Puzzle
Exec=puzzles-samegame
Terminal=false
Type=Application
Categories=Game;LogicGame;
Icon=puzzles-samegame-48d8
EOF

# Create desktop entry for sixteen
cat > $PKG/usr/share/puzzles/applications/puzzles-sixteen.desktop <<EOF
[Desktop Entry]
Encoding=UTF-8
Name=Sixteen
Comment=Puzzle
Exec=puzzles-sixteen
Terminal=false
Type=Application
Categories=Game;LogicGame;
Icon=puzzles-sixteen-48d8
EOF

# Create desktop entry for slant
cat > $PKG/usr/share/puzzles/applications/puzzles-slant.desktop <<EOF
[Desktop Entry]
Encoding=UTF-8
Name=Slant
Comment=Puzzle
Exec=puzzles-slant
Terminal=false
Type=Application
Categories=Game;LogicGame;
Icon=puzzles-slant-48d8
EOF

# Create desktop entry for solo
cat > $PKG/usr/share/puzzles/applications/puzzles-solo.desktop <<EOF
[Desktop Entry]
Encoding=UTF-8
Name=Solo
Comment=Puzzle
Exec=puzzles-solo
Terminal=false
Type=Application
Categories=Game;LogicGame;
Icon=puzzles-solo-48d8
EOF

# Create desktop entry for tents
cat > $PKG/usr/share/puzzles/applications/puzzles-tents.desktop <<EOF
[Desktop Entry]
Encoding=UTF-8
Name=Tents
Comment=Puzzle
Exec=puzzles-tents
Terminal=false
Type=Application
Categories=Game;LogicGame;
Icon=puzzles-tents-48d8
EOF

# Create desktop entry for twiddle
cat > $PKG/usr/share/puzzles/applications/puzzles-twiddle.desktop <<EOF
[Desktop Entry]
Encoding=UTF-8
Name=Twiddle
Comment=Puzzle
Exec=puzzles-twiddle
Terminal=false
Type=Application
Categories=Game;LogicGame;
Icon=puzzles-twiddle-48d8
EOF

# Create desktop entry for unequal
cat > $PKG/usr/share/puzzles/applications/puzzles-unequal.desktop <<EOF
[Desktop Entry]
Encoding=UTF-8
Name=Unequal
Comment=Puzzle
Exec=puzzles-unequal
Terminal=false
Type=Application
Categories=Game;LogicGame;
Icon=puzzles-unequal-48d8
EOF

# Create desktop entry for untangle
cat > $PKG/usr/share/puzzles/applications/puzzles-untangle.desktop <<EOF
[Desktop Entry]
Encoding=UTF-8
Name=Untangle
Comment=Puzzle
Exec=puzzles-untangle
Terminal=false
Type=Application
Categories=Game;LogicGame;
Icon=puzzles-untangle-48d8
EOF

# Include puzzlespanel in the package
cd $CWD/puzzlespanel-$PPVERSION
make
make install DESTDIR=$PKG
mkdir -p $PKG/usr/doc/puzzlespanel-$PPVERSION
cp -a $PPDOCS $PKG/usr/doc/puzzlespanel-$PPVERSION

# Strip binaries
cd $PKG
find . | xargs file | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

# Make sure ownerships and permissions are sane
cd $PKG
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# Make the package
makepkg -l y -c n $CWD/$NAME-$VERSION-$ARCH-$BUILD.tgz

# Calculate md5sum
cd $CWD/
md5sum $NAME-$VERSION-$ARCH-$BUILD.tgz > $NAME-$VERSION-$ARCH-$BUILD.md5

# Remove source-code and temporary install directories
# since they are not needed anymore
rm -rf $CWD/$NAME-$VERSION
rm -rf $CWD/puzzlespanel-$PPVERSION
rm -rf $PKG
